@@ -1,4 +1,4 @@
-#include <WINGs.h>
+#include <WINGs/WINGs.h>
 #include <WMaker.h>
 /*--------------------------------*-C-*---------------------------------*
  * File:	command.c
@@ -46,7 +46,7 @@ static const char rcsid[] = "$Id: command.c,v 1.20 1998/09/24 18:22:36 mason Exp
 #endif
 
 /*{{{ includes: */
-#include "rxvt.h"		/* NECESSARY */
+#include "wterm.h"		/* NECESSARY */
 
 #ifdef OFFIX_DND
 # include <X11/Xatom.h>
@@ -206,7 +206,7 @@ static const char rcsid[] = "$Id: command.c,v 1.20 1998/09/24 18:22:36 mason Exp
  *
  * By stealing a sequence to which other xterms respond, and sending the
  * same number of characters, but having a distinguishable sequence,
- * we can avoid having a timeout (when not under an rxvt) for every login
+ * we can avoid having a timeout (when not under an wterm) for every login
  * shell to auto-set its DISPLAY.
  *
  * This particular sequence is even explicitly stated as obsolete since
@@ -353,6 +353,7 @@ privileges(int mode)
 	break;
     }
 #else
+# error Warning, no seteuid/setegid avaliable
 # ifndef __CYGWIN32__
     switch (mode) {
     case IGNORE:
@@ -507,6 +508,14 @@ get_pty(void)
     static char     tty_name[] = "/dev/tty??";
     int             len = strlen(tty_name);
     char           *c1, *c2;
+    int            s;
+
+    ttydev = malloc(30);
+
+    if (openpty(&fd, &s, ttydev, NULL, NULL))
+      return -1;
+
+    goto Found;
 
     ptydev = pty_name;
     ttydev = tty_name;
@@ -1401,7 +1410,7 @@ lookup_key(XEvent * ev)
 		return;
 		break;
 
-	    /* rxvt extras */
+	    /* wterm extras */
 	    case XK_KP_Add:	/* Shift+KP_Add = bigger font */
 		change_font(0, FONT_UP);
 		return;
@@ -2468,13 +2477,13 @@ process_x_event(XEvent * ev)
 		    case Button3:
 #ifndef XTERM_SCROLLBAR
 			if (scrollbar_above_slider(ev->xbutton.y))
-# ifdef RXVT_SCROLL_FULL
+# ifdef WTERM_SCROLL_FULL
 			    scr_page(UP, TermWin.nrow - 1);
 # else
 			    scr_page(UP, TermWin.nrow / 4);
 # endif
 			else if (scrollbar_below_slider(ev->xbutton.y))
-# ifdef RXVT_SCROLL_FULL
+# ifdef WTERM_SCROLL_FULL
 			    scr_page(DN, TermWin.nrow - 1);
 # else
 			    scr_page(DN, TermWin.nrow / 4);
@@ -3306,7 +3315,7 @@ process_graphics(void)
 {
     unsigned char   ch, cmd = cmd_getc();
 
-#ifndef RXVT_GRAPHICS
+#ifndef WTERM_GRAPHICS
     if (cmd == 'Q') {		/* query graphics */
 	tt_printf((unsigned char *) "\033G0\n");	/* no graphics */
 	return;
@@ -3422,8 +3431,8 @@ main_loop(void)
 }
 
 /* ---------------------------------------------------------------------- */
-/* Addresses pasting large amounts of data and rxvt hang
- * code pinched from xterm and applied originally to rxvt-2.18
+/* Addresses pasting large amounts of data and wterm hang
+ * code pinched from xterm and applied originally to wterm-2.18
  * Hops
  */
 
@@ -3486,7 +3495,7 @@ v_writeBig(int f, char *d, int len)
 		    v_bufend = v_bufptr + len;
 		} else {
 		/* no memory: ignore entire write request */
-		    fprintf(stderr, "rxvt: cannot allocate buffer space\n");
+		    fprintf(stderr, "wterm: cannot allocate buffer space\n");
 		    v_buffer = v_bufstr;	/* restore clobbered pointer */
 		}
 	    }
