@@ -1,4 +1,4 @@
-#include <WINGs.h>
+#include <WINGs/WINGs.h>
 #include <WMaker.h>
 
 
@@ -39,7 +39,7 @@ static const char rcsid[] = "$Id: main.c,v 1.18 1998/09/24 19:22:44 mason Exp $"
 #endif
 
 #define INTERN			/* assign all global vars to me */
-#include "rxvt.h"		/* NECESSARY */
+#include "wterm.h"		/* NECESSARY */
  
 
 WMMenu *menu;
@@ -1075,7 +1075,7 @@ set_window_color(int idx, const char *color)
  *      46 = change logfile (not implemented)
  *      50 = change font
  *
- * rxvt extensions:
+ * wterm extensions:
  *      10 = menu
  *      20 = bg pixmap
  *      39 = change default fg color
@@ -1645,8 +1645,8 @@ main(int argc, char *argv[])
     putenv(windowid_string);
 /*    FREE(display_string); this cannot be freed */
 
-#ifdef RXVT_TERMINFO
-    putenv("TERMINFO=" RXVT_TERMINFO);
+#ifdef WTERM_TERMINFO
+    putenv("TERMINFO=" WTERM_TERMINFO);
 #endif
 
     if (Xdepth <= 2)
