@@ -33,7 +33,7 @@ static const char rcsid[] = "$Id: screen.c,v 1.29 1998/09/24 09:18:34 mason Exp
 #endif
 
 #define INTERN_SCREEN
-#include "rxvt.h"		/* NECESSARY */
+#include "wterm.h"		/* NECESSARY */
 
 #include <X11/Xatom.h>
 #include <X11/Xmd.h>		/* get the typedef for CARD32 */
@@ -1758,7 +1758,7 @@ set_multichar_encoding(const char *str)
  *                           GRAPHICS COLOURS                                * 
  * ------------------------------------------------------------------------- */
 
-#ifdef RXVT_GRAPHICS
+#ifdef WTERM_GRAPHICS
 /* PROTO */
 int
 scr_get_fgcolor(void)
@@ -2158,7 +2158,10 @@ scr_refresh(int type)
 	    ccol2 = Color_bg;
 	else
 	    ccol2 = Color_cursor2;
-	*srp = SET_FGCOLOR(*srp, ccol1) | SET_BGCOLOR(*srp, ccol2);
+	/* The cursor colours *must* be set separately - using an OR to  */
+	/* combine the two macros ORs both colours with their old values */
+	*srp = SET_FGCOLOR(*srp, ccol1);
+	*srp = SET_BGCOLOR(*srp, ccol2);
 #endif
 #ifdef MULTICHAR_SET
 	rt1 = *srp & RS_multiMask;
@@ -2178,7 +2181,9 @@ scr_refresh(int type)
 # ifndef NO_CURSORCOLOR
 	if (morecur) {
 	    cc2 = *srp & (RS_fgMask | RS_bgMask);
-	    *srp = SET_FGCOLOR(*srp, ccol1) | SET_BGCOLOR(*srp, ccol2);
+	    /* As before, the cursor colours *must* be set separately */
+	    *srp = SET_FGCOLOR(*srp, ccol1);
+	    *srp = SET_BGCOLOR(*srp, ccol2);
 	}
 # endif
 #endif
