@@ -38,7 +38,7 @@
 static const char rcsid[] = "$Id: xdefaults.c,v 1.12 1998/09/24 18:33:22 mason Exp $";
 #endif
 
-#include "rxvt.h"		/* NECESSARY */
+#include "wterm.h"		/* NECESSARY */
 
 /* #define DEBUG_RESOURCES */
 
@@ -587,7 +587,7 @@ my_strcasecmp(const char *s1, const char *s2)
 /*
  * Define key from XrmEnumerateDatabase.
  *   quarks will be something like
- *      "rxvt" "keysym" "0xFF01"
+ *      "wterm" "keysym" "0xFF01"
  *   value will be a string
  */
 /* ARGSUSED */
@@ -606,7 +606,7 @@ define_key(XrmDatabase * database, XrmBindingList bindings, XrmQuarkList quarks,
 
 /*
  * look for something like this (XK_Delete)
- * rxvt*keysym.0xFFFF: "\177"
+ * wterm*keysym.0xFFFF: "\177"
  *
  * arg will be
  *      NULL for ~/.Xdefaults and
